@@ -42,7 +42,7 @@ class DataClient:
                     else:
                         raise "database is pending..."
             except Exception as e:
-                print(e)
+                print(e, "retrying...")
                 sleep(1)
 
     def history(self, symbol, start_data, end_date, data_type, freq):
